@@ -41,7 +41,7 @@ methods :meth:`~ae.gui_app.MainAppBase.init_app` and :meth:`~HelpAppBase.ensure_
             framework_method_to_push_widget_to_top_most(widget)
             ...
 
-For to activate the help mode the widget to display the help texts have to be assigned to the main app attribute
+To activate the help mode the widget to display the help texts have to be assigned to the main app attribute
 :attr:`~HelpAppBase.help_layout` and to the framework app property :attr:`~ae.kivy_app.FrameworkApp.help_layout` via
 the :meth:`~ae.gui_app.MainAppBase.change_observable` method::
 
@@ -128,7 +128,7 @@ the example.
 pre- and post-change help texts
 -------------------------------
 
-For to display a different help message before and after the change of the flow id or the app state define a message
+to display a different help message before and after the change of the flow id or the app state define a message
 dict with the keys `''` (an empty string) and `'after'` like shown in the following example::
 
     {
@@ -206,7 +206,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.1.34'
+__version__ = '0.1.35'
 
 
 register_package_translations()
@@ -473,13 +473,15 @@ class TourBase:
         self._saved_app_states: Dict[str, Any] = dict()
 
         self.auto_switch_pages: Union[bool, int] = False
-        """ switch automatically tour pages within the seconds specified by :attr:`.page_data`['next_page_delay'].
+        """ enable/disable automatic switch of tour pages.
 
-        set to `True`, `1` or `-1` for to automatically switch tour pages; `True` and `1` will switch to the next page
+        set to `True`, `1` or `-1` to automatically switch tour pages; `True` and `1` will switch to the next page
         until the last page is reached, while `-1` will switch back to the previous pages until the first page is
-        reached;
-        `-1` and `1` automatically toggles at the first/last page the to other value (endless ping-pong until back/next
-        button gets pressed by the user).
+        reached; `-1` and `1` automatically toggles at the first/last page the to other value (endless ping-pong until
+        back/next button gets pressed by the user).
+
+        the seconds to display each page before switching to the next one can be specified via the item value of the
+        the dict :attr:`.page_data` dict with the key `'next_page_delay'`.
         """
 
         self.page_data: Dict[str, Any] = dict(help_vars=dict())
@@ -608,7 +610,7 @@ class TourBase:
             delay, self.prev_page if self.auto_switch_pages < 0 else self.next_page)
 
     def reset_app_flow(self):
-        """ delayed reset of flow path/id for to be processed after dispatch of popups dismiss. """
+        """ delayed reset of flow path/id to be processed after dispatch of popups dismiss. """
         self.main_app.vpo("TourBase.reset_app_flow")
         # optionally set/overwrite current app flow, e.g. like:
         # main_app = self.main_app
@@ -632,7 +634,7 @@ class TourBase:
         main_app.setup_app_states(self._saved_app_states)
 
     def setup_app_flow(self):
-        """ setup app flow and load page data for to prepare a tour page. """
+        """ setup app flow and load page data to prepare a tour page. """
         self.main_app.vpo(f"TourBase.setup_app_flow page_data={self.page_data}")
 
         self.load_page_data()
@@ -713,7 +715,7 @@ class TourBase:
         layout.prev_text = page_data.get('back_text', get_text('back')) if page_idx > 0 else ""
 
     def start(self):
-        """ prepare app for tour start. """
+        """ prepare app tour start. """
         self.main_app.vpo("TourBase.start")
         self.reset_app_states()
         self.setup_app_flow()
@@ -741,7 +743,7 @@ class TourBase:
 
 
 class TourDropdownFromButton(TourBase):
-    """ generic tour base class for to auto-explain a dropdown menu, starting with the button opening the dropdown. """
+    """ generic tour base class to auto-explain a dropdown menu, starting with the button opening the dropdown. """
     determine_page_ids = '_v_'
 
     def setup_app_flow(self):
